# RUINS climate data and regional model app

![GitHub release (latest by date)](https://img.shields.io/github/v/release/hydrocode-de/RUINSapp?color=success&logo=Github)
![PyPI](https://img.shields.io/pypi/v/ruins-app?color=success&logo=PyPI)
[![Test RUINS](https://github.com/hydrocode-de/RUINSapp/actions/workflows/main.yml/badge.svg)](https://github.com/hydrocode-de/RUINSapp/actions/workflows/main.yml)
[![Docker Image CI](https://github.com/hydrocode-de/RUINSapp/actions/workflows/docker-image.yml/badge.svg)](https://github.com/hydrocode-de/RUINSapp/actions/workflows/docker-image.yml)
[![codecov](https://codecov.io/gh/hydrocode-de/RUINSapp/branch/main/graph/badge.svg?token=SFxENKltZb)](https://codecov.io/gh/hydrocode-de/RUINSapp)


This is a compilation of tools to assess and visualise climate data and climate model projections at the German North Sea coast. This app is intended to especially focus on the treatment of uncertainties within the data and model projections.

For more information about the RUINS project, see our website. 

All data is public domain from the respectively quoted sources. The tools are developed in Python under MIT license without any liability.
Please join, fork, reuse...

## Development State

* [Pre-Release Checklist](https://github.com/hydrocode-de/RUINSapp/issues/20)

### Applications

* [Weather Explorer Overview](https://github.com/hydrocode-de/RUINSapp/issues/21)
* [Climate Explorer Overview](https://github.com/hydrocode-de/RUINSapp/issues/29)
* [Management Explorer Overview](https://github.com/hydrocode-de/RUINSapp/issues/32)
